package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````P"4```````!``````````$"Q````
M`````````$``.``-`$``'``;``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````%`:````````4!H`````````
M$`````````$````%`````"``````````(``````````@````````A3T`````
M``"%/0`````````0`````````0````0`````8`````````!@`````````&``
M```````P1P```````#!'`````````!`````````!````!@```-"K````````
MT+L```````#0NP```````%`$````````T!0`````````$`````````(````&
M````X*L```````#@NP```````."[````````$`(````````0`@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``"4GP```````)2?````````E)\```````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````T*L```````#0NP```````-"[````
M````,`0````````P!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50#SF[CINT$_^ME"YEV$*-;$`(LE0@0````0````
M`0```$=.50```````P````(``````````````!$````_````!`````@````@
M'!``!4`$AB@"0`20A@"$@@D`($D@!`BXHA%%N@`""@`````_````0@```$4`
M``!&````30```$X```!0````5````%4```!7````6````%L```!=````7P``
M````````````;L7?'\[>1RUK?YI\+L6;MB#_Y`[59-1\V7%8'.)'Q@%"^M>'
MK$OCP+KCDGS"Y3\L^J%L8+,!BV]K"4/69J_,9L6YG$!"1=7LQ(D%D(@'<-,Y
M\HL<#13BGMK-XYXS8MOM%8PES`PZEPM6I)N6I]VC:WZIG)O19<YMX*<""FL:
MGE`*BA!7H^#[20````````````````````````````````````#A````$@``
M``````````````````````"*`0``$@````````````````````````#D`0``
M$@````````````````````````#"`0``$@`````````````````````````!
M````(`````````````````````````#K`0``$@``````````````````````
M``!J`@``$@```````````````````````````@``$@``````````````````
M``````!%`0``$@`````````````````````````^`@``$@``````````````
M``````````!4`@``$@````````````````````````!T````$@``````````
M``````````````!"`P``$@````````````````````````#<````$@``````
M```````````````````C`@``$@`````````````````````````5`@``$@``
M``````````````````````#3`0``$@````````````````````````!C`@``
M$@`````````````````````````_`@``$@````````````````````````!S
M`@``$@`````````````````````````W`0``$@``````````````````````
M```%`0``$@````````````````````````!S`0``$@``````````````````
M``````"W`0``$@````````````````````````#*`0``$@``````````````
M``````````#3`@``$@````````````````````````!@`0``$@``````````
M``````````````#Y`0``$@````````````````````````"%`0``$@``````
M``````````````````"W`@``$@````````````````````````"P`@``$@``
M```````````````````````3`0``$@`````````````````````````=````
M(``````````````````````````W`@``$@````````````````````````!4
M````$@````````````````````````"C`0``$@``````````````````````
M``!L`0``$@````````````````````````"#````$@``````````````````
M``````"/````$@`````````````````````````L`0``$@``````````````
M``````````#R````$@````````````````````````!&````$@``````````
M``````````````#F````$@````````````````````````!&`@``$@``````
M``````````````````!5`0``$@````````````````````````#`````$@``
M``````````````````````#Q`0``$@````````````````````````!^`0``
M$@````````````````````````"A`@``$@````````````````````````!Z
M`@``$@````````````````````````!C````$@``````````````````````
M``"I`@``$@`````````````````````````.`@``$@``````````````````
M``````"D````$@`````````````````````````C`0``$@``````````````
M``````````"]`0``$@````````````````````````";`0``$@``````````
M```````````````I`@``$@`````````````````````````L````(```````
M```````````````````'`@``$@`````````````````````````<`@``$@``
M``````````````````````"3`@``$@````````````````````````!+`P``
M$@`/`-!!````````!@$```````!W`P``$@`/`$`W````````[`<```````#$
M`@``$@`/`+`C````````!P(````````?`P``$@`/```N````````!0``````
M```+!```$@`/`!`N`````````@(```````!!!```$@`/`#`_````````G0(`
M``````#W`P``$``9`"#```````````````````!>`P``$@`/`"`P````````
M)0````````"$`P``$@`/`'!9````````GP$```````"<`P``$0`1``!@````
M````!`````````#;`P``$``9`*#0```````````````````#!```$@`/`!`M
M````````,``````````8!```$@`/`#`V````````"P$````````J!```$@`/
M`)`U````````=`````````"/`P``$``8``#```````````````````!K`P``
M$@`/`%`P````````W`````````#)`@``$0`9`$#`````````"`````````!7
M`P``$``8`"#```````````````````#*`@``(0`9`$#`````````"```````
M``#1`P``$0`8`!C`````````"`````````!<`@``$0`9`&#`````````"```
M```````/`P``$@`/`&!=`````````0````````#!`P``$@`/``!=````````
M70````````"5`P``$@`/`,`E````````*P`````````X!```$@`/`!!9````
M````5`````````"1`P``(``8``#```````````````````#1````$0`9`"#`
M````````!`````````#+`@``(0`9`$#`````````"``````````P`P``$@`/
M`!`V````````'0````````"$`@``(@````````````````````````"K`P``
M$@`/`$`M````````OP````````#M`P``$@`/`!!;````````ZP$```````"S
M````$0`9`##``````````0````````#@`P``$@`/`#`Q````````7`0`````
M````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;W!E;C8T`')E860`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`97AI
M=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK
M9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE
M;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`;'-T870V-`!?
M7W-T<FYC<'E?8VAK`&]P96YD:7(`<W1D97)R`&=E='5I9`!R96%D;&EN:P!S
M=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`
M;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV
M:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L:6)P97)L+G-O+C4N,S0`;&EB<'1H
M<F5A9"YS;RXP`&QI8F,N<V\N-@!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E
M;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU
M<`!?961A=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I
M<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?
M96YD`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI
M=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A
M;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`
M1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`
M1TQ)0D-?,BXS,P`````"``,``@`"``$``@`"``(``0`$``(``0`"``$``@`"
M``4``@`$``(``0`!``$``P`"``8``0`"``,``@`"``$``0`'``$``P`"``$`
M`0`!``$``0`!``@``0`!``(``P`"``(``0`"``(``0`!``(``P`(``$``@`"
M``@``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``$``@`!``(`
M`0`!``$``0`!``$``@`!``(``0`!``$``0````$``0#U`@``$````"````!U
M&FD)```#`%<$`````````0`&``4#```0`````````'09:0D```@`8P0``!``
M``"4D98&```'`&\$```0````<AEI"0``!@!Z!```$````!1I:0T```4`A@0`
M`!````"SD98&```$`)`$```0````=1II"0```@!7!````````-"[````````
M"`````````"@)@```````-B[````````"`````````!@)@````````C`````
M````"``````````(P````````!C`````````"`````````#88@```````,"_
M````````!@````4``````````````,B_````````!@````D`````````````
M`-"_````````!@```!X``````````````-B_````````!@```"$`````````
M`````."_````````!@```"D``````````````.B_````````!@```#,`````
M`````````/"_````````!@```#L``````````````/B_````````!@```%P`
M`````````````"#`````````!0```%D``````````````##`````````!0``
M`%\``````````````$#`````````!0```$\``````````````&#`````````
M!0```%,```````````````B^````````!P````$``````````````!"^````
M````!P````(``````````````!B^````````!P````,``````````````""^
M````````!P````0``````````````"B^````````!P````8`````````````
M`#"^````````!P````<``````````````#B^````````!P````@`````````
M`````$"^````````!P````H``````````````$B^````````!P````L`````
M`````````%"^````````!P````P``````````````%B^````````!P````T`
M`````````````&"^````````!P````X``````````````&B^````````!P``
M``\``````````````'"^````````!P```!```````````````'B^````````
M!P```!$``````````````("^````````!P```!(``````````````(B^````
M````!P```!,``````````````)"^````````!P```!0``````````````)B^
M````````!P```!4``````````````*"^````````!P```!8`````````````
M`*B^````````!P```!<``````````````+"^````````!P```!@`````````
M`````+B^````````!P```!D``````````````,"^````````!P```!H`````
M`````````,B^````````!P```!L``````````````-"^````````!P```!P`
M`````````````-B^````````!P```!T``````````````."^````````!P``
M`!\``````````````.B^````````!P```"```````````````/"^````````
M!P```"(``````````````/B^````````!P```",```````````````"_````
M````!P```"0```````````````B_````````!P```"4``````````````!"_
M````````!P```"8``````````````!B_````````!P```"<`````````````
M`""_````````!P```"@``````````````"B_````````!P```"H`````````
M`````#"_````````!P```"L``````````````#B_````````!P```"P`````
M`````````$"_````````!P```"T``````````````$B_````````!P```"X`
M`````````````%"_````````!P```"\``````````````%B_````````!P``
M`#```````````````&"_````````!P```#$``````````````&B_````````
M!P```#(``````````````'"_````````!P```#0``````````````'B_````
M````!P```#4``````````````("_````````!P```#8``````````````(B_
M````````!P```#<``````````````)"_````````!P```#@`````````````
M`)B_````````!P```#D``````````````*"_````````!P```#H`````````
M`````*B_````````!P```#P``````````````+"_````````!P```#T`````
M`````````+B_````````!P```#X`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%S9\``$B%P'0"_]!(@\0(PP```````````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)2*<``!H-@```.F`_/___R52G```9I``````````
M`$%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*```
M`$B)1"0H,<#H)_[__TB+-?";``!(BSWQFP``2(GRZ'$Y``"`/2J<````=2_H
M8_W__TB)!82L``!(B<=(A<`/A(@!``#HF_S__XL]]9L``.CP_?__QH#7"0``
M`(L]XYL``.C>_?__BSW8FP``@(@J!````NC,_?__@(@J!````8M$)!R->`1$
MC6`#2&/_2,'G`^@^_?__2(M\)!!(B<%(B04/K```2(L'2(D!2(T%-3T``$B)
M00A(BP5_FP``2(E!$$B-!2(]``!(B4$8BT0D'(/X`0^.Z0```$B#QPB#P`.Z
M!`````\?@`````!,BP=(8_*#P@%(@\<(3(D$\3G0=>M(F$B+/;*K``!$B>)%
M,<!(QP3!`````$B--:4'``#HH/W__T&)Q(7`=%-(BSV*JP``2(UL)"3H./S_
M_S'`2(GN2(T]?SL``.B'`0``2(7`=#U(BSUCJP``Z*;[___H,?W__TB+1"0H
M9$@K!"4H````=6-(@\0X1(G@74%<PTB+/3>K``#HROW__T&)Q.N<2(L]%JL`
M`$B%_W0'Z%0<``#KL$B-/=,Z``!(B>[H(P$``$B)!?2J``!(B<=(A<!TDNO9
MN`0```#I-?___[\!````Z([]___H6?O__V8/'X0``````#'M28G17DB)XDB#
MY/!05$R-!8HW``!(C0TC-P``2(T]S/W___\5YID``/0/'T0``$B-/2F:``!(
MC04BF@``2#GX=!5(BP6VF0``2(7`=`G_X`\?@`````###Q^``````$B-/?F9
M``!(C37RF0``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!:69``!(A<!T"/_@
M9@\?1```PP\?@`````#S#Q[Z@#W]F0```'4K54B#/8*9````2(GE=`Q(BSV&
MF0``Z!G]___H9/___\8%U9D```%=PP\?`,,/'X``````\P\>^NEW____#Q^`
M`````$%7059!54%455-(@^P(2(7_#X2Q````3(LM<ID``$V%[0^$H0````^V
M!TF)_TB)]83`=`0\/75813'V38ME`$V%Y'0R36/V3(GK9@\?1```3(GR3(G^
M3(GGZ%+Y__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!7$%=
M05Y!7\,/'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/'X``````
M3"GK3XUD-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!!5D%505154TB![*``
M``!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@K
M!"4H````#X4A`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HR_C__TR-
M+1@X``!)B<1(A<!TNTR)Y^CT^O__2(7`#X2C````@'@3+DB-6!-U"8![`0!T
MWP\?`(!X$RX/A)X```!(B>_HUOC__TB)WTF)QNC+^/__08U\!@)(8__H[OG_
M_TF)V4F)Z$R)Z4F)QDB)Q[X!````,<!(Q\+_____Z"S[__],B?=(B>;HP?C_
M_TR)]X/X_W00BT0D&"4`\```/0!```!T6>C$]___3(GWZ)SW__],B>?H5/K_
M_TB%P`^%8/___P\?`$R)Y^C@^/__2(GOZ#CX___I\O[__P\?`(![`2X/A5C_
M__^`>P(`#X0@____Z4G___\/'X``````Z)O^___KI>@D^/__#Q]``%5(B?U(
M@>R@````9$B+!"4H````2(F$))@````QP$B)YNB*]___A<!U-HM4)!B!X@#P
M``"!^@!```!T"('Z`*```'4>O@(```!(B>_HO_G__X7`#Y3`#[;`ZP</'T0`
M`#'`2(N4))@```!D2"L4)2@```!U"4B!Q*````!=P^B=]___9F8N#Q^$````
M``!FD$%6NO\/``!!54%428GT54B)_4B-/7$V``!(@>P8$```9$B+!"4H````
M2(F$)`@0```QP$F)Y4R)[NC"]O__A<!^3HU0_TQC\D*`/#0`#X5]````A=)T
M.4R)\KXO````3(GOZ-GW__](A<!T)(L]+I8``.@I^/__3(GQ3(GJ2(GN2(G'
MZ!CY___K'V8/'T0``(L]"I8``.@%^/__3(GB2(GN2(G'Z#?W__](BX0D"!``
M`&1(*P0E*````'4<2('$&!```%U!7$%=05[##Q]$``!,8_#I?____^BS]O__
M#Q\`05=!5D%505152(GU4TB)^TB#[!AD2(L$)2@```!(B40D"#'`,<"`/CT/
ME,!(`<5(B>_H:?;__TB-="0$2(G?28G$,<#H!_S__TB%P`^$!@$``$B)QTF)
MQ>A#]O__23G$#X;2````3&-T)`1)P>8##[8#A,`/A)X!```\/0^$E@$``$B)
MV`\?``^V4`%(@\`!A-)T!8#Z/77O2"G82)A,BRT[E0``2HU\(`+H(??__TT!
M]4F)10!(A<!T5DB+!1Z5``!(C4L!2HL4,`^V`X@"A,!T(CP]=0WK'`\?@```
M``"$P'01#[8!2(/"`4B#P0&(`CP]=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#
MP`&$R77O2(M$)`AD2"L$)2@````/A0<!``!(@\086UU!7$%=05Y!7\,/'T``
M,<!F#Q]$```/ME0%`$&(5`4`2(/``832=>[KO0\?0`!,BSV!E```28,_``^$
MM@```$R)^$4Q[9!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+!8^D``"%
MP'5;QP6!I````0```$B)]^@I]O__2(7`#X1A____36/U3(G^2(G'2<'F`TR)
M\NB[]O__2(D%%)0``$B)P4&-10%$B6PD!$B82,<$P0````#IB/[__V8/'X0`
M`````$R)_^AH]O__2(D%X9,``$B)P4B%P`^$!O___TUC]4G!Y@/KNP\?0``Q
MP.E__O__OA````!%,>WI7____^A_]/__9F8N#Q^$```````/'T``2(/L"(L]
M=I,``.AQ]?__BSUKDP``Z&;U__](BQ4'DP``2(T-P'(``$B--4HS``!(B<?H
MB?7__XL]0Y,``.@^]?__3(T%MS0``$4QR4B-%3T2``!(B<=,B<%(C34U,P``
M2(/$".FG]?__#Q^``````$B#[`B+/0:3``#H`?7__TB+%:*2``!(@\0(2(T-
M5W(``$B)QTB--=XR``#I(/7__T%455-(@>P@(```9$B+!"4H````2(F$)!@@
M```QP$B)Y4R-I"00$```Z"+S__],C0V@,@``N@$0``!(B>]!B<!(C0W#,@``
MO@$````QP.C]]?__N@`0``!,B>9(B>_HW?+__T4QP(7`>"Z->`%(B<-(8__H
M>/3__TF)P$B%P'082&/;3(GF2(G'2(G:Z"_T___&!!@`28G`2(N$)!@@``!D
M2"L$)2@```!U#TB!Q"`@``!,B<!;74%<P^@1\___D.D[____9F8N#Q^$````
M``!!5T%6055!5$F)]%5(B?U(C3TR,@``4TB![,@0``!D2(L$)2@```!(B80D
MN!```#'`2(UT)!SH9?C__[XO````2(GO2(G#Z.7R__](A<!T0#'`2(GN2(T]
M]3$``.CO^___2(GH2(N4)+@0``!D2"L4)2@````/A8(!``!(@<3($```6UU!
M7$%=05Y!7\,/'P!(B>_H6/+__TR)YTR-);PQ``!!B<;HMO3__TR)YDB)Q^A+
M]/__28G%2(7`=)-!C48!08!]``!,C35^,@``B40D#`^$Q@```&8/'X0`````
M`$B%VW033(GN2(G?Z.#R__^%P`^$A````$R)[^CP\?__ZPEF#Q]$``#&`@")
MP8/H`4ACT$P!ZH`Z+W3M`TPD#('Y_P\```^/)?___TR-O"2P````3(GQ38GH
M,<!(@^P(N@`0``"^`0```$R)_U5,C0T,,0``Z"?T__](C70D,$R)_^BZ\?__
M6EF%P'40BT0D."4`\```/0"```!T5$R)YC'_Z'KS__])B<5(A<`/A+[^__]!
M@'T```^%0____TB%VW0%@#LN=!E,C2V8,```N0$```#I8____P\?A```````
M@'L!`'2VZ]\/'X0``````+X!````3(G_Z!/S__^%P'6;3(G^2(T]9C```.A@
M^O__3(G_Z&CS___I9_[__^C^\/__9F8N#Q^$```````/'P`/M@=)B?B$P'07
M9@\?1```2(/'`3PO#[8'3`]$QX3`=>],B<##9F8N#Q^$``````!(A?\/A,<`
M``!5@#\`2(G]#X2B````Z)7P__](C50%_T@YU7(4Z9L```!F#Q]$``!(@^H!
M2#G5="6`.B]T\D@YU0^#?@```$B#Z@%(.=5T#H`Z+W0H2(/J`4@YU77R@'T`
M+W142(T]M2\``%WIK_+__P\?@`````"`.B]U"4B#Z@%(.=5R\D@IZC'`2(U*
M`DB!^0`0``!W&$B#P@&Y`!```$B)[DB-/86/``#HD/'__UW#9@\?1```2(T]
M1R\``%WI6_+__T@YU76SZY(/'T``2(T]+R\``.E$\O__#Q]``$%7059!54%4
M55-(C1TQ+P``2(/L&&1(BP0E*````$B)1"0(,<!(C6PD!&8/'T0``#'`2(GN
M2(G?Z$/U__](A<!T-DAC5"0$2(L%PHX``$B-!-!(BU`(2(D02(72=-)FD$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'<PN``"0,<!(B>Y(B=_H\_3__TB%
MP'0V2&-4)`1(BP5RC@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(T=A"X``)`QP$B)[DB)W^BC]/__2(7`=#9(8U0D!$B+
M!2*.``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!(C1T]+@``D#'`2(GN2(G?Z%/T__](A<!T-DAC5"0$2(L%THT``$B-!-!(
MBU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-)?0M``"0
M,<!(B>Y,B>?H`_3__TB%P'0V2&-4)`1(BP6"C0``2(T$T$B+4`A(B1!(A=)T
MTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=M"T``)`QP$B)[DB)W^BS
M\___2(7`=#9(8U0D!$B+!3*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!,C2T9+0``D#'`2(GN3(GOZ&/S__](A<!T-DAC
M5"0$2(L%XHP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$R-/2`M``"0,<!(B>Y,B?_H$_/__TB%P'0V2&-4)`1(BP62C```
M2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TU
MVBP``)`QP$B)[DR)]^C#\O__2(7`=#9(8U0D!$B+!4*,``!(C0302(M0"$B)
M$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1V4+```D#'`2(GN
M2(G?Z'/R__](A<!T-DAC5"0$2(L%\HL``$B-!-!(BU`(2(D02(72=-)FD$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'>(K``"0,<!(B>Y(B=_H(_+__TB%
MP'0V2&-4)`1(BP6BBP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(GN2(T]^RL``.C9\?__2(G&2(7`=`I,B?<QP.AW]?__
M2(GN2(T]ZRL``#'`Z+;Q__](B<9(A<!T#DB-/><K```QP.A0]?__2(GN2(T]
MX2L``#'`Z(_Q__](B<9(A<!T.4R)[S'`Z"WU__](BT0D"&1(*P0E*````'5$
M2(/$&$R)YTB--<LK```QP%M=05Q!74%>05_I_O3__TB)[DB-/9\K```QP.@]
M\?__2(G&2(7`=+A,B?\QP.C;]/__ZZSHA.O__P\?0`!(@^P89$B+!"4H````
M2(E$)`B+!6B*``"#^/]T&TB+5"0(9$@K%"4H````=4)(@\08PV8/'T0``$B-
M="0$2(T]VRH``#'`Z-7P__](B<(QP$B%TG02#[8"/#`/E<*$P`^5P`^VP"'0
MB043B@``ZZ[H#.O__V9F+@\?A```````D$B#[`CH!^O__XG'Z+#J__](A<!T
M`TB+`$B#Q`C##Q\`055!5$R-)>,J``!52(G]3(GG4TB#[!AD2(L$)2@```!(
MB40D"#'`2(UT)`3H3_#__TB%P'0(@#@`2(G#=3)(BT0D"&1(*P0E*`````^%
MM````$B)[DB#Q!A,B><QP%M=05Q!7>G'\___#Q^``````$B)[DB)Q^C5[/__
M2(7`="!(BT0D"&1(*P0E*````'5V2(/$&%M=05Q!7<,/'T0``$B)[^@HZO__
M2(G?28G%Z!WJ__])C7P%`NA#Z___2(/L"$F)Z+X!````4TC'PO____](B<=)
MB<5,C0U@*0``2(T-1BH``#'`Z'3L__]86DB+1"0(9$@K!"4H````=0A,B>[I
M3____^C5Z?__#Q]$``!!5T%63(TU#2D``$%505154TB![(B!``!(B3PD2(UL
M)!Q,B?=(B>YD2(L$)2@```!(B80D>($``$B-!=<H``!(QT0D,`````!(QX0D
MB`````````!(QT0D4`````!(B40D*$B-!4`I``!(B40D:$B-!8HI``!(B40D
M<$B-!44I``!(B40D>$B-!7HI``!(B80D@````$B-!6\I``!(B40D2#'`Z,CN
M__](A<!T#(`X`$F)Q`^%EP0``.@BZ?__B<?HR^C__TB%P`^$V@,``$R+*$V%
M[0^$S@,``$R)[^C>Z/__2(U\``'H!.K__T4/MD4`28G$183`=#Y-B>=(C1T1
M*0``#Q]$``!%#[;`3(G_2(G9O@$```!(Q\+_____,<!)@\4!28/'`N@CZ___
M10^V10!%A,!UT4B-7"1@2(T];2@``.L4#Q\`2(M["$B#PPA(A?\/A"\!``!(
MB>XQP.@-[O__28G%2(7`=-V`.`!TV$B)Q^@X\/__A<!TS$R)[^BLZO__28G`
M2(7`#X3X````3(G'3(E$)`CH(^C__TR)YTB)P^@8Z/__1(V\`P0$``!-8_],
MB?_H->G__T%43(T-;"<``$B-#4XH``!)B<5(C05-*```2,?"_____[X!````
M4$R+1"083(GO,<#H7^K__TR)[[[``0``Z#+G__]?05B#^/]U$NCUYO__1(L(
M08/Y$0^%!`,``$B-M"20````3(GOZ#CG__^)PX7`#X2^````2(L$)$V)Z+X!
M````13'D2(L]V(8``$B-%8$H``!(BP@QP.C'Z?__2(N$)'B!``!D2"L$)2@`
M```/A7<%``!(@<2(@0``3(G@6UU!7$%=05Y!7\,/'P`QVTR-+6DG``#K&0\?
M1```2&/#3(MLQ"!-A>UT.T&`?0``=#1,B>^#PP'H^>[__X7`=-U,B>_H;>G_
M_TF)P$B%P`^%P?[__TACPTR+;,0@387M=<D/'T``13'`Z:C^__\/'X0`````
M`(N$)*@````E`/```#T`0```#X4K____1(ND)*P```#HS.;__T$YQ`^%%?__
M_XN$)*@````E_P$``#W``0``#X7^_O__3(G_Z+3G__](B>Y(C3VC)@``28G$
M,<#H(.S__TB)QDB%P`^$-`(``$B+!"1(BSCH://__TF)QTB%P`^$'`(``$R)
M_^A$YO__2(G"@_@#?CQ(F$B--9HF``!(B50D"$F-?`?\Z`3G__^%P'4@2(M4
M)`B#^@0/A(8#``"-0OM(F$&`/`<O#X1V`P``9I"+!0J%``"#^/\/A"$#``!(
MC3V9)0``A<`/A,@!``!(C37W)0``,<!(C2UR)@``Z"WO__],C3U4)@``Z%'E
M__]52,?"_____TV)Z%!,C0T>)0``O@$```!,B>=(C0T?)@``,<#H*.C__UA:
MZT0/'T``Z,OD__^#.!%U2.@1Y?__@\,!2(/L"$V)Z%5,C0W?)```3(GYO@$`
M``!32,?"_____TR)YU`QP.CDY___2(/$(+[``0``3(GGZ+/D__^#^/]TKDR)
M[^AFY/__3(GW3(GF,<#HB>[__TR)Y^A1^O__Z;7]__\/'T``,=M(C3T])0``
MZQ(/'T0``$ACPTB+?,1`2(7_=#A(B>XQP(/#`>B>ZO__2(7`=.&`.`!TW$B)
MQ^A,Y___28G%2(7`#X7J^___2&/#2(M\Q$!(A?]UR+\-````3(TMZB0``.CB
MY?__0;A3````28G$Z=W[__](BP0D38GHO@$```!%,>1(BSWN@P``2(T55R4`
M`$B+"#'`Z-WF___I$?W__P\?A```````2(G'Z)CY__](BX0D>($``&1(*P0E
M*`````^%>`(``$B!Q(B!``!,B>=;74%<05U!7D%?Z:CF__\/'X0``````$B+
M!"1,BSCIV/W__\<%*H,```````!,B?\Q]C'`Z-[E__](C3VV(P``B<6%P`^$
M&_[__[H"````2,?&[O___XG'Z#KF__](C9PD<`$``+H&````B>](B=[HH^3_
M_X"\)'`!````=0Z`O"1Q`0``0P^$>@$``#'2,?:)[^@`YO__,<#HN1L``$F)
MQ^L/#Q]``$B)WDR)_^@%'```N@"```!(B=Z)[^A6Y/__B<*%P'_@B>](C:PD
M(`$``$B-'<,C``#HZN/__TR)_DB)[^AO'0``2(V$)$`!``!(B40D"$F)QTB-
MA"1H`0``2(D$)`\?`$0/MD4`3(G_2(G9O@$```!(Q\+_____,<!(@\4!28/'
M`NBJY?__3#D\)'742(T%K2,``,:$)&@!````4/]T)!!(C0UJ(P``38GH3(GG
M,<"^`0```$R-#54B``!(Q\+_____Z&GE__]97NF4_?__9I!(C3UX(@``,<!(
MB>Y(B3PDZ&OH__](A<`/A([^__\/M@"$P`^$@_[__SPP#X1[_O__QP6E@0``
M`0```$B+/"3IJOS__TB+!"1(BU`(2(72#X1[_/__2(G72(D4).AOXO__2(/X
M`P^&9?S__TB+%"1(C37&(@``2(U\`OSH,./__TB+%"2%P$P/1/KI0?S__X"\
M)'(!``!!#X5X_O__@+PD<P$``$,/A6K^__^`O"1T`0``2`^%7/[__X"\)'4!
M``!%#X5._O__N@(```!(Q\;&____B>_H1N3__[HI````2(G>B>_HM^+__TB-
M!8`B``!04^G9_O__Z.3A__\/'T``055!5%5(@^P0BSWA@```9$B+!"4H````
M2(E$)`@QP.C,XO__BSW&@```2(G%Z+[B__\/MI6P````2(UL)`1(C3T>(0``
M2(GNB)"Q````,<#H*^?__TB%P'0)@#@Q#X2U`0``,<#HEO'__XL]@(```.A[
MXO__N0,```"Z`0```$B-->DA``!(B<?H,N+__TF)Q$B%P'0X2(M`$(L]4(``
M`$R+*.A(XO__2(T5PB$``$B)QTR)[NAVX?__28M$)!!,BR!!]D0D#D`/A9(!
M``"+/1R```#H%^+__[D#````N@$```!(C36,(0``2(G'Z,[A__])B<1(A<!T
M/DB-/3`@``!(B>XQP.AUYO__BSW??P``28G%2(7`#X03`0``28M$)!!,BR#H
MQN'__TR)ZDB)QTR)YNCXX/__BSVR?P``Z*WA__^Z`0```$B--2DA``!(B<?H
MN>'__XL]DW\``$F)Q.B+X?__3(GF2(T5'B$``$B)Q^BYX/__BSUS?P``Z&[A
M__](B>Y(C3V<'P``QH"Q`````#'`Z.;E__](B06WCP``28G$2(7`=#^^P`$`
M`$R)Y^B*W___C5`!@_H!=@F#^!$/A;0```!(BT0D"&1(*P0E*`````^%O0``
M`$B#Q!!=05Q!7<,/'P!(BSUQCP``Z!SV__](B05=CP``28G$2(7`=:9(C3TN
M(0``,<#H#^'__P\?@`````"`>`$`#X1(_O__Z3S^__]F#Q^$``````!(BP4I
MCP``3(LH28M$)!!,BR#HJ>#__TR)[DR)Y^C^Y___Z>'^__]F#Q^$``````"+
M/8I^``#HA>#__TR)YDB)Q^C:X/__Z5/^__^)P4B+!=R.``!,B>)(C3W2(```
M2(LP,<#HB.#__^A#W___#Q\`051)B?Q54TB#[!!D2(L$)2@```!(B40D"#'`
MZ&#N__\/MA!(B<6$TG089@\?1```2(/``8#Z+P^V$$@/1.B$TG7NBP7X?0``
M387D#Y7#@_C_=&V%P`^5P"'#A-MU(DB+1"0(9$@K!"4H````#X6/````2(/$
M$%M=05S##Q]$``!!@#PD`'37N@0```!(C37_'@``2(GOZ/7=__^%P'6_2(M$
M)`AD2"L$)2@```!U4DB#Q!!,B>=;74%<Z?'D__^0,<!(C70D!$B-/1$>``#H
M#>3__TB%P'0+#[8`A,!T!#PP=0_'!5-]````````Z6S____'!41]```!````
MZ5G____H.M[__V8N#Q^$``````!!5TB)_DR-3SA!5D%505154TB![)@"``!D
M2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(````!)B=`/'X``````08L!28LY
M28/`$$F#P0@/R(G`2(GY28E`\$B)^$C!Z2!(P>@H2,'O."4`_P``2`GX2(G/
M2,'A"$C!YQB!X0``_P")_T@)^$@)R$F)0/A-.=!UKDB-N@`"```/'X``````
M2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?IUU4R+
M#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,
M"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I(
M"<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)
MR$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-
MB>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G5
M2#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!
MX!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%
M3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!
MB=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0L
MF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!
M`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`
M3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)
M^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG!
M[`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!
M2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))
MP>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_
M3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+
M;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A
M^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY
M@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,
MB>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!
MRDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-
M2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H
M`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!
MY`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'0
M2<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC!
M[P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-
M">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY
M@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,
M"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!
MX@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P
M````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M
M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(
MP>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-
MI!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"
M28G(2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;
M2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''
M1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$
MB>=,"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B
M!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@
M3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!(
M"?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)
M^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD
M$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))
MB<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`
M20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'K
MV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)
MP$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'5
M3(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H
M&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#
ME"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G1
M2<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)
MB?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4Q
MZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH
M2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)
MP>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!
M``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%
MB=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%
M3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1`
M`0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)
MY$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE
M2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPA
MPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG!
M[`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)
M_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)
M"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP
M00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``
M20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)
MY$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N
M&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)
M\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G!
M[`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!
MTDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5(
M(?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G6
M00'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&
M30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)
MT4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!
MY05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+
MM"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>
MB?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)
M^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,
M(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ
M2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T
M38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)
MSD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-
M"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(
M`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!
MYQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``
M2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-
M08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)
MP$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B
M38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$
MB=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT
M38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q
M\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)
MT4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)
MR4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4Q
MZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)
M\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)
MTD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4Q
MX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)
MZDR+K"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)
MR4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4Q
MT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)
MX4R+I"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)
MTD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q
M\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+
ME"0X`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)
MR4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4Q
MZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+
MM"1(`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)
MTD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!
MQT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)
MZDR+K"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)
MR4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4Q
MXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,
MBZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G2
M2<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%
MB<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>
MB<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!
M^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$
M)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^@`R/__2(/L"+^`````Z!+)__^Z
MB:O-[[G^W+J8OO#ATL-(QP`!(T5G2(E0"$B)2!!(QT`8=E0R$$B)<"!(QT`H
M`````$C'0#``````QT!X`````$B#Q`C#9F8N#Q^$``````"005=(8\)!5DF)
MQD%5051)B?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!
MZ!U(`=!(B4<P2&-'>(7`#X7M````08/^/P^.*P$``$&#[D!%B?=!P>\&18UO
M`4G!Y09)`=T/'T0``/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5
M(/,/;UOP#Q%=,.C1Z/__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$B-30A(
M@^'X28E4)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+
M=!4`2(DT$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`
M=.%!#[95`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;U`````2(U\!0!(
MB=Y!*<5%.?5%#T_N36/]3(GZZ#7'__]!BT0D>$0!Z$&)1"1X@_A`=9),B>=%
M*>Y,`?OH]>?__^G+_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6___
M_Y!!5DR-=CA!54%454B)]5-(BT8H2(G[1(MF*$2+;C!(P>@#@^`_00_,00_-
MC4@!2)C&1`8X@$ACP4P!\(/Y.`^.%`$``+Y`````*<YT#S'2B=&#P@'&!`@`
M.?)R\TB)[^ALY___9@_OP`\113A)QT8P`````$$/$48000\11B!$B6UP2(GO
M1(EE=.A"Y___2(M%`$B)[TC!Z!B(`TB+10!(P>@0B$,!2(M%`(AC`DB+10"(
M0P-(BT4(2,'H&(A#!$B+10A(P>@0B$,%2(M%"(AC!DB+10B(0P=(BT402,'H
M&(A#"$B+11!(P>@0B$,)2(M%$(AC"DB+11"(0PM(BT482,'H&(A##$B+11A(
MP>@0B$,-2(M%&(AC#DB+11B(0P](BT4@2,'H&(A#$$B+12!(P>@0B$,12(M%
M((AC$DB+12"(0Q-;74%<05U!7NG/P___#Q^``````+HX````,?\IRH/Z"')*
MB=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"[?[__X/B
M^#'`B<:#P`A(B3PQ.=!R\^G6_O__#Q^$``````#VP@1U(X72#X3!_O__Q@``
M]L("#X2U_O__,<EFB4P0_NFI_O__#Q\`QP``````QT00_`````#ID_[__P\?
M1```05=,C3W'7@``059)B=9!54F)]4%408G\54B-+;A>``!33"G]2(/L".C3
MPO__2,']`W0;,=L/'P!,B?),B>Y$B>=!_Q3?2(/#`4@YW77J2(/$"%M=05Q!
M74%>05_##Q\`PV8N#Q^$```````/'T0``$B+#9%B``#I),3__TB#[`A(@\0(
MPP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!54T52`%-9
M4U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4U`"UE`"TM```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\
M.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F
M:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET
M(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM
M>2`D;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C
M($Y/5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?
M<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B
M1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*
M;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@
M9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@-"`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@
M97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R
M($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@
M("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z
M("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A
M9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I
M;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T
M85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R
M('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO
M)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@
M("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@
M)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I
M.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@
M/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=
M*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE
M>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F
M*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H
M/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV
M93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U
M=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O
M=70B73L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O
M=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E
M;B!M>2`D=&@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H*3L*
M8VQO<V4@)'1H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*#0P("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&-A8VAE7VYA;64@+CT@(EPP0T%#2$4B.PIM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("L@;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R
M*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I
M+`HD4$%27TU!1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R
M871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;W5T<R@B4F5A9&EN9R!-151!+GEM;"XN+B(I
M.PII9B`H;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CI<<RHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["FEF("AM>2`H)&-L96%N*2`]("1M971A(#U^("]>7',K8VQE86XZ
M("@N*BDD+VTI('L*)&-L96%N(#U^("]>7',J?%QS*B0O9SL*)$5.5GM005)?
M0TQ%04Y](#T@,2!I9B`D8VQE86X["GT*?0IP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*
M;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M
M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P````$;`SOX````
M'@```(R`__]$`0``#(3__VP!```<A/__``8``"R&__\4`0``'(?__X0!``#L
MA___T`$``%R)__\4`@``[(G__S@"``#,BO__=`(```R-___``@``?(W__]@"
M``"LC?__\`(``&R.__\D`P``?([__S@#``",D/__F`,``+R0__^L`P``G)'_
M_]P#``#\E?__*`0``'R6__]$!```G);__UP$``"LE___N`0``)R?__^(!0``
M/*+__[P%``!,H___+`8``'RY__]\!@``W+G__Y0&``!\N___X`8``&R]__\D
M!P``S+W__VP'``#<O?__A`<``!0``````````7I2``%X$`$;#`<(D`$'$!0`
M```<````$(7__RL``````````````!0``````````7I2``%X$`$;#`<(D`$`
M`"0````<````0'___X`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````
M1````)B"__\(``````````````!(````7````)"%___-`````$(.$(\"0@X8
MC@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X0
M0@X(20L`0````*@````4AO__;`$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.
M,(,&1P[0`7X*#C!!#BA!#B!"#AA"#A!"#@A+"P`@````[````$"'__^#````
M`$$.$(8"2@ZP`0)Q"@X000X(00LX````$`$``*R'___=`````$(.$(X"1PX8
MC0-"#B",!$0.*(8%40[`(`*C"@XH00X@0@X80@X00@X(1@M(````3`$``%"(
M__\Q`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.4`,5`0H.
M.$$.,$$.*$(.($(.&$(.$$(."$4+%````)@!``!$BO__:0````!$#A`"8`X(
M%````+`!``"<BO__,`````!$#A!6#@@`,````,@!``"TBO__OP````!"#A",
M`D$.&(8#00X@@P1'#L!``J<*#B!$#AA!#A!"#@A!"Q````#\`0``0(O__P4`
M````````7````!`"```\B___`@(```!"#A"/`D(.&(X#0@X@C01"#BB,!40.
M,(8&2PXX@P='#H`B`F0*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P*O#H@B3@Z0
M(EH.B")!#H`B````$````'`"``#LC/__)0`````````L````A`(```B-___<
M`````$H.$(8"`F(*Q@X(3`MY"@X(1PM("L8."$4+2PX(Q@!(````M`(``+B-
M__]<!````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!TL.4`,"!`H.
M.$T.,$$.*$(.($(.&$(.$$(."$4+&``````#``#,D?__=`````!$#B!M"@X(
M1PL``!0````<`P``,)+__QT`````1`X06`X(`%@````T`P``.)+__PL!````
M0@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"0@H.*$8.($$.&$(.$$(."$P+9`H.
M*$$.($$.&$(.$$(."$8+80Y(20Y08PY(00Y`````S````)`#``#LDO__[`<`
M``!"#A"/`D(.&(X#20X@C01"#BB,!4$.,(8&00XX@P='#L"#`@.E`0[(@P)E
M#M"#`ET.R(,"0@[`@P("=@H..$0.,$$.*$(.($(.&$(.$$(."$0+`W@!#LB#
M`DL.T(,"7@[(@P)!#L"#`EP.R(,"1`[0@P)0#MB#`DL.X(,"2P[`@P(#!@$*
M#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P,L`0[(@P)$#M"#`F@.R(,"00[`@P("
M^`H.R(,"00[0@P)%"S````!@!```#)K__YT"````0@X0C0)"#AB,`T$.((8$
M1`XP`]8!"@X@00X80@X00@X(1`M`````E`0``'B<__\&`0```$(.$(P"1`X8
MA@-!#B"#!$0.,`)K"@X@00X800X00@X(1@MS"@X@1`X800X00@X(1@L``"@`
M``#8!```%'[__P<"````0@X0C`)!#AB&`T0.4`.<`0H.&$0.$$(."$$+3```
M``0%```8G?__,!8```!"#A"/`DD.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='
M#M`%`P@6"@XX00XP00XH0@X@0@X80@X00@X(00L````4````5`4``/BR__]4
M`````$0.$`)/#@A(````;`4``$"S__^?`0```$(.$(\"10X8C@-%#B"-!$(.
M*(P%1`XPA@9%#CB#!T<.0`+E"@XX00XP00XH0@X@0@X80@X00@X(0PL`0```
M`+@%``"4M/__ZP$```!"#A".`D8.&(T#0@X@C`1!#BB&!40.,(,&`S8!"@XH
M00X@0@X80@X00@X(3`L```````!$````_`4``$"V__]=`````$(.$(\"20X8
MC@-%#B"-!$4.*(P%1`XPA@9(#CB#!T<.0&H..$$.,$$.*$(.($(.&$(.$$(.
M"``4````1`8``%BV__\!```````````````0````7`8``%"V__\,````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````*`F````````8"8````````!`````````.4"
M`````````0````````#U`@````````$`````````!0,````````,````````
M```@````````#0````````!\70```````!D`````````T+L````````;````
M``````@`````````&@````````#8NP```````!P`````````"`````````#U
M_O]O`````*`#````````!0````````"X#0````````8`````````H`0`````
M```*`````````)L$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````H!0```````!0`````````
M!P`````````7`````````"@5````````!P````````"H$P````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````!@3````````____;P`````"````````
M`/#__V\`````5!(```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#@NP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,```````"6(P``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#88@```````$=#
M0SH@*$1E8FEA;B`Q,2XS+C`M-"D@,3$N,RXP```N<VAS=')T86(`+FEN=&5R
M<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E
M+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N
M<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````&`,````````8`P```````!P````````````````````!````````
M````````````$P````<````"`````````#@#````````.`,````````@````
M````````````````"````````````````````"8````'`````@````````!8
M`P```````%@#````````)`````````````````````0`````````````````
M```Y````!P````(`````````?`,```````!\`P```````"``````````````
M```````$````````````````````1P```/;__V\"`````````*`#````````
MH`,```````#\``````````8`````````"````````````````````%$````+
M`````@````````"@!````````*`$````````&`D````````'`````0````@`
M````````&`````````!9`````P````(`````````N`T```````"X#0``````
M`)L$```````````````````!````````````````````80```/___V\"````
M`````%02````````5!(```````#"``````````8``````````@`````````"
M`````````&X```#^__]O`@`````````8$P```````!@3````````D```````
M```'`````@````@```````````````````!]````!`````(`````````J!,`
M``````"H$P```````(`!````````!@`````````(`````````!@`````````
MAP````0```!"`````````"@5````````*!4````````H!0````````8````7
M````"``````````8`````````)$````!````!@``````````(``````````@
M````````%P````````````````````0```````````````````",`````0``
M``8`````````("`````````@(````````(`#```````````````````0````
M`````!``````````EP````$````&`````````*`C````````H",````````(
M````````````````````"``````````(`````````*`````!````!@``````
M``"P(P```````+`C````````S#D``````````````````!``````````````
M``````"F`````0````8`````````?%T```````!\70````````D`````````
M```````````$````````````````````K`````$````"``````````!@````
M`````&````````"2/P``````````````````"````````````````````+0`
M```!`````@````````"4GP```````)2?````````_```````````````````
M``0```````````````````#"`````0````(`````````D*````````"0H```
M`````*`&```````````````````(````````````````````S`````X````#
M`````````-"[````````T*L````````(````````````````````"```````
M```(`````````-@````/`````P````````#8NP```````-BK````````"```
M``````````````````@`````````"`````````#D````!@````,`````````
MX+L```````#@JP```````!`"````````!P`````````(`````````!``````
M````FP````$````#`````````/"]````````\*T````````0`@``````````
M````````"``````````(`````````.T````!`````P``````````P```````
M``"P````````(`````````````````````@```````````````````#S````
M"`````,`````````(,`````````@L````````(`0```````````````````@
M````````````````````^`````$````P````````````````````(+``````
M```>`````````````````````0`````````!``````````$````#````````
M`````````````````#ZP`````````0$```````````````````$`````````
(````````````
